//-----------------------------------------------------------------------------
// volumebyregion.m
//
// Example of an Animated Volume bar using Regions
// (Improved, no longer requires HiddenVolume)
//
// written by FrisbeeMonkey
//-----------------------------------------------------------------------------

//                            USING THIS SCRIPT:
//*****************************************************************************
//  1.  Define the following in your XML:
//    <layer id="VolumeAnim" image="?.?.Volume" x="?" y="?" move="0" tooltip="Volume"/>
//
//      Change the position(x,y) and image of "VolumeAnim" to the specifics
//      of your layer.
//  2.  Define your gradient maps with your other elements using:
//        <bitmap id="player.map.volume" file="player/player-map-volume.png"/>
//        and
//        <bitmap id="player.map.volume2" file="player/player-map-volume2.png"/>
//      If you need help creating a map file, check:
//        http://www.stefanweb.com/wa3/tutorials.html#UsingMaps
//  3.  Make sure your ticker is called "SongTicker" and is in the same group as
//      "VolumeAnim".  If you don't have a ticker, add one now.
//  4.  Copy this script (and volumebyregion.maki) to your scripts folder.
//  5.  If you don't have volumebyregion.maki, compile this script.
//  6.  Add this line to the group that contains your layer and SongTicker
//        <script id="volume" file="scripts/volumebyregion.maki"/>
//  7.  Refresh your skin(F5) and try it out.
//
//  NOTE: The second gradient map should be identical to the first except you
//        should change the pure black RGB(0,0,0) to RGB(1,1,1).  This makes
//        sure that none of the volume bar is showing while off.
//*****************************************************************************

// Never forget to include std.mi
#include "../../../lib/std.mi"

// Declare local functions for use in script
Function setVolumeAnim(int volValue);
Function updateVolume(int x, int y);

// Declare global variables for use in script
Global Layer Volume;
Global Map VolumeMap, VolumeMap2;
Global Timer SongTickerTimer;
Global Boolean VolumeChanging;

// When the script/skin is loaded, do this
System.onScriptLoaded() {
	Group ScriptGrp = getScriptGroup();

	// Get Volume Layer and SongTicker
	Volume = ScriptGrp.findObject("Player.volume");

	// Initialize our timer
	SongTickerTimer = new Timer;
	SongTickerTimer.setDelay(750);

	// Initialize Maps
	VolumeMap = new Map;
	VolumeMap.loadMap("player.map.Volume");
	VolumeMap2 = new Map;
	VolumeMap2.loadMap("player.map.Volume2");

	//Set Initial Volume Setting
	setVolumeAnim(System.getVolume());
}

// Updates display and SongTicker on Volume changes
System.onVolumeChanged(int newVol) {
	setVolumeAnim(newVol);
}

//sets the Animation to correct frame
setVolumeAnim(int Value) {
	Region r = new Region;
	r.loadFromMap(VolumeMap2, Value, 1);
	Volume.setRegion(r);
	delete r;
}

// Handles Volume Mouse Events
Volume.onLeftButtonDown(int x, int y) {
	VolumeChanging = 1;
	updateVolume(x, y);
}
Volume.onLeftButtonUp(int x, int y) {
	if (VolumeChanging) {
		VolumeChanging = 0;
		updateVolume(x, y);
	}
}
Volume.onMouseMove(int x, int y) {
	if (VolumeChanging) {
		updateVolume(x, y);
	}
}

// Updates Volume Image and System Position
updateVolume(int x, int y) {
	int newValue = VolumeMap.getValue(x - Volume.getLeft(), y - Volume.getTop());
	System.setVolume(newValue);
}

System.onScriptUnloading() {
	delete SongTickerTimer;
	delete VolumeMap;
	delete VolumeMap2;
}